import { Express, Request, Response } from "express";
import { Config as SshConfig } from "node-ssh";
import { IWebServiceEndpoint, IExpressRequestHandler } from "@hyperledger/cactus-core-api";
import { AuthorizationOptionsProvider } from "@hyperledger/cactus-core";
import { IAsyncProvider, LogLevelDesc } from "@hyperledger/cactus-common";
import { IEndpointAuthzOptions } from "@hyperledger/cactus-core-api";
export interface IDeployContractEndpointOptions {
    logLevel?: LogLevelDesc;
    sshConfigAdminShell: SshConfig;
    corDappsDir: string;
    cordaStartCmd?: string;
    cordaStopCmd?: string;
    authorizationOptionsProvider?: AuthorizationOptionsProvider;
}
export declare class DeployContractJarsEndpoint implements IWebServiceEndpoint {
    readonly options: IDeployContractEndpointOptions;
    static readonly CLASS_NAME = "DeployContractJarsEndpoint";
    private readonly log;
    private readonly authorizationOptionsProvider;
    get className(): string;
    constructor(options: IDeployContractEndpointOptions);
    getAuthorizationOptionsProvider(): IAsyncProvider<IEndpointAuthzOptions>;
    get oasOperation(): {
        operationId: string;
        "x-hyperledger-cactus": {
            http: {
                path: string;
                verbLowerCase: string;
            };
        };
        summary: string;
        parameters: never[];
        requestBody: {
            content: {
                "application/json": {
                    schema: {
                        $ref: string;
                    };
                };
            };
        };
        responses: {
            "200": {
                description: string;
                content: {
                    "application/json": {
                        schema: {
                            $ref: string;
                        };
                    };
                };
            };
            "400": {
                description: string;
                content: {
                    "application/json": {
                        schema: {
                            $ref: string;
                        };
                    };
                };
            };
        };
    };
    /**
     * Returns the `operationId` that connects this endpoint to it's definition in
     * the openapi-spec.ts file.
     */
    get operationId(): string;
    /**
     * Returns the endpoint path to be used when installing the endpoint into the
     * API server of Cactus.
     */
    getPath(): string;
    getVerbLowerCase(): string;
    getExpressRequestHandler(): IExpressRequestHandler;
    registerExpress(expressApp: Express): Promise<IWebServiceEndpoint>;
    handleRequest(req: Request, res: Response): Promise<void>;
    private doDeploy;
    private stopCordaNode;
    private startCordaNode;
}
